#  Copyright 2021 Rikai Authors
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from typing import Mapping

import numpy as np
import pandas as pd

from rikai.mixin import ToNumpy


def convert_tensor(row):
    """Convert row into rikai semantic objects."""
    if not isinstance(row, (Mapping, pd.Series)):
        # Primitive values
        return row
    tensors = {}
    for key, value in row.items():
        if isinstance(value, dict):
            tensors[key] = convert_tensor(value)
        elif isinstance(value, (list, tuple)):
            tensors[key] = np.array([convert_tensor(elem) for elem in value])
        elif isinstance(value, ToNumpy):
            tensors[key] = value.to_numpy()
        else:
            tensors[key] = value
    return tensors



#  Copyright 2020 Rikai Authors
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

"""Rikai Feature Store
"""

from rikai.numpy import array, empty, wrap
from .__version__ import version

__all__ = ["array", "empty", "wrap", "version"]
